#' A vector containing names of the built-in approximation methods.
#'
#' @description
#' `approximationMehodsInside` is a vector containing names of the built-in approximation methods.
#'
#' @return This function returns a vector of strings.
#'
#'
#' @examples
#'
#' # check the names
#'
#' approximationMehodsInside
#'
#' @export




# approximation methods from this package

approximationMehodsInside <- c("ExpectedValueCore","TriangSuppPreserving","AmbiguityValuePreserving")
